/* Wrapper that disables warnings from Fortify function definitions.

   Copyright (C) 2020 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* This glibc header override disables the warnings
   "warning: read called with bigger length than size of the destination buffer"
   "warning: readlink called with bigger length than size of destination buffer"
   "warning: readlinkat called with bigger length than size of destination buffer"
   "warning: getcwd caller with bigger length than size of destination buffer"
   "warning: please use getcwd instead, as getwd doesn't specify buffer size"
   "warning: confstr called with bigger length than size of destination buffer"
   "warning: getgroups called with bigger group count than what can fit into destination buffer"
   "warning: ttyname_r called with bigger buflen than size of destination buffer"
   "warning: getlogin_r called with bigger buflen than size of destination buffer"
   "warning: gethostname called with bigger buflen than size of destination buffer"
   "warning: getdomainname called with bigger buflen than size of destination buffer"
   seen with clang 9.  */

#ifdef __clang__
# include <sys/cdefs.h>
# undef __warndecl
# define __warndecl(name, msg) extern void name (void)
# undef __warnattr
# define __warnattr(msg)
#endif

#include_next <bits/unistd.h>

#ifdef __clang__
# undef __warndecl
# define __warndecl(name, msg) \
  extern void name (void) __attribute__((__diagnose_if__ (1, msg, "warning")))
# undef __warnattr
# define __warnattr(msg) __attribute__((__diagnose_if__ (1, msg, "warning")))
#endif
   