/* Wrapper that disables warnings from Fortify function definitions.

   Copyright (C) 2020 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* This glibc header override disables the warnings
   "warning: wmemcpy called with length bigger than size of destination buffer"
   "warning: wmemmove called with length bigger than size of destination buffer"
   "warning: wmemset called with length bigger than size of destination buffer"
   "warning: wcsncpy called with length bigger than size of destination buffer"
   "warning: wcpncpy called with length bigger than size of destination buffer"
   "warning: fgetws called with bigger size than length of destination buffer"
   "warning: mbsrtowcs called with dst buffer smaller than len * sizeof (wchar_t)"
   "warning: wcsrtombs called with dst buffer smaller than len"
   seen with clang 9.  */

#ifdef __clang__
# include <sys/cdefs.h>
# undef __warndecl
# define __warndecl(name, msg) extern void name (void)
# undef __warnattr
# define __warnattr(msg)
#endif

#include_next <bits/wchar2.h>

#ifdef __clang__
# undef __warndecl
# define __warndecl(name, msg) \
  extern void name (void) __attribute__((__diagnose_if__ (1, msg, "warning")))
# undef __warnattr
# define __warnattr(msg) __attribute__((__diagnose_if__ (1, msg, "warning")))
#endif
